@@ -6,6 +6,13 @@ import os
 from pymongo import MongoClient
 
 
+def getTemplateUuidFromName(pattern, name):
+    for t in pattern.templates:
+        if t.name == name:
+            return t.uuid
+    return None
+
+
 def isString(var):
     return isinstance(var, str if sys.version_info[0] >= 3 else basestring)
 
@@ -309,7 +316,7 @@ def getProject(project_name):
 
 def getProjectNames():
     """Returns the list of the projects's names."""
-    return list(db.list_collection_names())
+    return sorted(db.list_collection_names())
 
 
 def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
@@ -353,17 +360,20 @@ def getGraphInfo(pattern, keys):
         pattern (MgvPattern): the pattern.
         keys (list of str): path of the graph from the pattern name to its name.
     Returns
-        dict: a dictionary with a uuid value and a template_name value.
+        dict: a dictionary with a uuid value and a template_uuid value.
     """
     project_name = pattern.project.name
-    try:
-        pid = db[project_name].find_one({'code': 'Pattern', 'name': pattern.name, 'parent': pattern.project.uuid},
-                                        {"_id": 1})['_id']
-        g = db[project_name].find_one({'code': 'Graph', 'parent': pid, 'path': ':'.join(keys)},
-                                      {'template_name': 1})
-        return {'code': 'Graph', 'uuid': g['_id'], 'template_name': g['template_name']}
-    except:
-        return {'template_name': ''}
+    pat = db[project_name].find_one({'code': 'Pattern', 'name': pattern.name, 'parent': pattern.project.uuid},
+                                    {"_id": 1})
+    if pat is None:
+        return {'template_uuid': ''}
+    g = db[project_name].find_one({'code': 'Graph', 'parent': pat['_id'], 'path': ':'.join(keys)},
+                                  {'template_name': 1, 'template_uuid': 1})
+    if g is None:
+        return {'template_uuid': ''}
+    if 'template_uuid' not in g.keys():
+        g['template_uuid'] = getTemplateUuidFromName(pattern, g['template_name'])
+    return {'code': 'Graph', 'uuid': g['_id'], 'template_uuid': g['template_uuid']}
 
 
 def getGraphVars(pattern, keys):
@@ -446,12 +456,14 @@ def getObjects(graph):
         g = db[project_name].find_one({'code': 'Graph', '_id': graph.uuid}, {'template_name': 1})
     else:
         g = db[project_name].find_one({'code': 'Graph', 'name': graph.getName(), 'path': ':'.join(graph.path),
-                                       'parent': graph.pattern.uuid}, {'template_name': 1})
+                                       'parent': graph.pattern.uuid}, {'template_name': 1, 'template_uuid': 1})
 
     if g is None:
         return None
+    if 'template_uuid' not in g.keys():
+        g['template_uuid'] = getTemplateUuidFromName(graph.pattern, g['template_name'])
     graphObject['uuid'] = g['_id']
-    graphObject['template_name'] = g['template_name']
+    graphObject['template_uuid'] = g['template_uuid']
     graphObject['variables'] = []
     graphObject['groups'] = []
     for data in db[project_name].find({'parent': g['_id']}):
